/*
 * Exadel Flamingo
 * Copyright (C) 2008 Exadel, Inc.
 * 
 * Exadel Flamingo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation
 * 
 * HessianEntityValidator.fx
 * 
 * Last modified by: $Author: apleskatsevich $
 * $Revision: 994 $   $Date: 2008-04-10 16:03:31 +0300 (Thu, 10 Apr 2008) $
 */

package com.exadel.flamingo.javafx;

import javafx.ui.*;
import java.awt.event.*;
import javax.swing.*;
import com.exadel.flamingo.javafx.FlamingoServiceFactory;

/**
 * This component allows validating user text input against Hibernate Validator annotations on the server.
 * @author apleskatsevich
 */

public class HessianEntityValidator {
    attribute destination:String;
    attribute source:Widget;
    attribute property:String;
    attribute returnedMessage:String;
    attribute required:Boolean;
    attribute valid:Boolean;
    
    public
    operation validate():String;
    
    operation doValidation(value:String);
}

operation HessianEntityValidator.HessianEntityValidator() {
    valid = true;
}

/**
 * Executes validation call to the server. Returns empty string if passed value is valid.
 *
 * @param value Validated value
 * @return Validation message
 */
operation HessianEntityValidator.doValidation(value:String){
    if (not required and value == "") {
        valid = true;
        returnedMessage = "";
    } else {
        var msg:String = FlamingoServiceFactory.getHessianEntityValidator().validate("{destination}.{property}", value);
        if (msg == null) {
            valid = true;
            returnedMessage = "";
        } else {
            valid = false;
            returnedMessage = msg;
        }
    }
    return returnedMessage;
}

trigger on HessianEntityValidator.source = newValue {
    var v = this;
    newValue.getComponent().addFocusListener(new FocusListener() {
        operation focusLost(e : FocusEvent) {
            var field:<<javax.swing.text.JTextComponent>> = (<<javax.swing.text.JTextComponent>>)e.getComponent();
            v.doValidation(field.getText());
        }
        
        operation focusGained(arg0 : FocusEvent) {
        }
    });
}

/**
 * Performs validation of value contained in <code>source</code>.
 */
operation HessianEntityValidator.validate():String {
    return this.doValidation(((<<javax.swing.text.JTextComponent>>)source.getComponent()).getText());
}
